@@ -19,14 +19,11 @@ import numpy as np
 import random
 
 
-class BertOneByOne(nn.Module):
-    def __init__(self, model_config, maxlen=512):
+class OneByOne(nn.Module):
+    def __init__(self, tokenizer, pretrained, maxlen=512):
         super().__init__()
-        if 'albert_chinese' in model_config:
-            self.tokenizer = BertTokenizer.from_pretrained(model_config)
-        else:
-            self.tokenizer = AutoTokenizer.from_pretrained(model_config)
-        self.pretrained = AutoModel.from_pretrained(model_config)
+        self.tokenizer = tokenizer
+        self.pretrained = pretrained
         self.model = nn.Linear(self.pretrained.config.hidden_size, self.tokenizer.__len__())
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         self.maxlen = maxlen
@@ -39,8 +36,8 @@ class BertOneByOne(nn.Module):
         negative_targets = batch_data['ntarget']
         masks = batch_data['mask']
 
-        tokens_tensor = torch.tensor(inputs).to(self.device)
-        mask_tensors = torch.tensor(masks).to(self.device)
+        tokens_tensor = torch.as_tensor(inputs).to(self.device)
+        mask_tensors = torch.as_tensor(masks).to(self.device)
 
         outputs = self.pretrained(tokens_tensor, attention_mask=mask_tensors)
         sequence_output = outputs[0]
@@ -52,7 +49,7 @@ class BertOneByOne(nn.Module):
                 'prob_list': []
             }
             start = batch_data['start'][0]
-            logit_prob = softmax(prediction_scores[0][start]).data.tolist()
+            logit_prob = softmax(prediction_scores[0][start],dim=0).data.tolist()
             prob_result = {self.tokenizer.decode([id]): prob for id, prob in enumerate(logit_prob)}
             prob_result = sorted(prob_result.items(), key=lambda x: x[1], reverse=True)
             result_dict['prob_list'].append(sorted(logit_prob, reverse=True))
@@ -60,8 +57,8 @@ class BertOneByOne(nn.Module):
             result_dict['label_map'].append(prob_result[0])
             outputs = result_dict
         else:
-            loss_tensors = torch.tensor(targets).to(self.device)
-            negativeloss_tensors = torch.tensor(negative_targets).to(self.device)
+            loss_tensors = torch.as_tensor(targets).to(self.device)
+            negativeloss_tensors = torch.as_tensor(negative_targets).to(self.device)
             loss_fct = nn.CrossEntropyLoss(ignore_index=-1)  # -1 index = padding token
             masked_lm_loss = loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
                                       loss_tensors.view(-1))
