@@ -71,6 +71,13 @@ class TestEval(unittest.TestCase):
             self.assertTrue(s[1]['EM'] == 1)
             self.assertTrue(s[1]['F1'] == 1)
 
+        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval.add_record("input", "ab", "abb[SEP]acc[SEP]ab c", task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 0)
+            self.assertTrue(s[1]['F1'] > 0)
+
         eval = tfkit.utility.eval_metric.EvalMetric()
         eval.add_record("input", "a b c", "a b b[SEP]a c c[SEP]", task='default')
         for s in eval.cal_score('emf1'):
@@ -78,7 +85,15 @@ class TestEval(unittest.TestCase):
             self.assertTrue(s[1]['EM'] == 0)
             self.assertTrue(s[1]['F1'] > 0)
 
+        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval.add_record("input", "", "a b b[SEP]a c c[SEP]", task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 0)
+            self.assertTrue(s[1]['F1'] == 0)
+
     def testNLG(self):
+
         eval = tfkit.utility.eval_metric.EvalMetric()
         eval.add_record("input", "a b c", "a b c[SEP]a c c[SEP]", task='default')
         for s in eval.cal_score('nlg'):
