@@ -45,7 +45,6 @@ class EvalMetric:
 
     def add_record(self, input, predicted, target, task='default'):
         input = input.strip()
-
         if isinstance(target, str):
             if "[SEP]" in target:
                 targets = [t.strip() for t in target.split("[SEP]")]
@@ -69,7 +68,7 @@ class EvalMetric:
         self.tasks[task]['predicted_list'].append(predicted.split(" ") if " " in predicted else list(predicted))
         self.tasks[task]['target'].append(target)
         self.tasks[task]['targets'].append(targets)
-        self.tasks[task]['target_list'].append(target[0].split(" ") if " " in target[0] else list(target[0]))
+        self.tasks[task]['target_list'].append(target.split(" ") if " " in target else list(target))
 
     def get_record(self, task='default'):
         return self.tasks[task]
@@ -86,7 +85,7 @@ class EvalMetric:
                     f1_list = [0]
                     for target in task['targets'][pos]:
                         equal = False
-                        if _normalize_answer(predict) == _normalize_answer(target):
+                        if _normalize_answer(predict) == _normalize_answer(target) and len(predict) > 0:
                             equal = True
                         if equal:
                             em_list.append(1)
@@ -109,9 +108,10 @@ class EvalMetric:
             if "classification" in metric:
                 from sklearn.metrics import classification_report
                 from sklearn.preprocessing import MultiLabelBinarizer
-                mlb = MultiLabelBinarizer().fit([list(self.target_list[task_name].keys())])
+                mlb = MultiLabelBinarizer().fit(
+                    [t.split(" ") if " " in t else list(t) for t in self.target_list[task_name].keys()])
                 result = classification_report(
-                    mlb.transform(task['targets']),
-                    mlb.transform(task['predicteds']),
+                    mlb.transform(task['target_list']),
+                    mlb.transform(task['predicted_list']),
                     target_names=list(mlb.classes_))
             yield (task_name, result)
